@@ -40,22 +40,22 @@ class PartSelection: public QWidget, public TraceItemView
     Q_OBJECT
 
 public:
-    explicit PartSelection(TopLevelBase*, QWidget* parent = 0);
+    explicit PartSelection(TopLevelBase*, QWidget* parent = nullptr);
 
-    QWidget* widget() Q_DECL_OVERRIDE { return this; }
-    QString whatsThis() const Q_DECL_OVERRIDE;
-    void setData(TraceData*) Q_DECL_OVERRIDE;
+    QWidget* widget() override { return this; }
+    QString whatsThis() const override;
+    void setData(TraceData*) override;
 
     PartAreaWidget* graph() { return _partAreaWidget; }
 
-    void saveOptions(const QString& prefix, const QString& postfix) Q_DECL_OVERRIDE;
-    void restoreOptions(const QString& prefix, const QString& postfix) Q_DECL_OVERRIDE;
+    void saveOptions(const QString& prefix, const QString& postfix) override;
+    void restoreOptions(const QString& prefix, const QString& postfix) override;
 
-signals:
+Q_SIGNALS:
     void partsHideSelected();
     void partsUnhideAll();
 
-public slots:
+public Q_SLOTS:
     void selectionChanged();
     void doubleClicked(TreeMapItem*);
     void itemSelected();
@@ -67,8 +67,8 @@ public slots:
 
 private:
     // reimplementations of TraceItemView
-    CostItem* canShow(CostItem*) Q_DECL_OVERRIDE;
-    void doUpdate(int, bool) Q_DECL_OVERRIDE;
+    CostItem* canShow(CostItem*) override;
+    void doUpdate(int, bool) override;
 
     // helper for doUpdate
     void selectParts(const TracePartList& list);
